@@ -9,7 +9,7 @@ use warnings;
 use Taint::Runtime qw(untaint is_tainted);
 use Time::HiRes 'time';
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 our $Debug;
 
 sub new {
@@ -368,7 +368,7 @@ File::Write::Rotate - Write to files that archive/rotate themselves
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -556,16 +556,37 @@ replaces it with a simple daily/monthly/yearly period.
 
 =item * And lastly, FWR supports compressing and rotating compressed old files.
 
-Using separate processes like Unix B<logrotate> utility means having to deal
+Using separate processes like the Unix B<logrotate> utility means having to deal
 with yet another race condition. FWR takes care of that for you (see the
 compress() method). You also have the option to do log compression in the same
 script/process if you want, which is convenient.
 
 =back
 
+There is no significant overhead difference between FWR and LDFR (FWR is
+slightly faster than LDFR on my testing).
+
 L<Tie::Handle::FileWriteRotate> and Log::Dispatch::FileWriteRotate, which use
 this module.
 
+=head1 FAQ
+
+=head2 Why use autorotating log?
+
+Mainly convenience and low maintenance. You no longer need a separate rotator
+like the Unix B<logrotate> utility (which when accidentally disabled or
+misconfigured will cause your logs to stop being rotated and grow indefinitely).
+
+=head2 What is the downside of using FWR (and LDFR)?
+
+Mainly performance overhead, as every write() involves locking to make it safe
+to use with multiple processes. Tested on my Core i5 3.1 GHz desktop, writing
+log lines in the size of ~ 200 bytes, raw writing to disk (SSD) has the speed of
+around 3.4mil/s, while using FWR it comes down to around 19.5k/s.
+
+However, this is not something you'll notice or need to worry about unless
+you're logging near that speed.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
